@@ -1,6 +1,9 @@
 from django.db import models
 
 # Create your models here.
+
+from django.http import HttpResponseRedirect
+
 import datetime
 from ckeditor.fields import RichTextField
 
@@ -27,28 +30,21 @@ class Category(models.Model):
 	def __unicode__(self):
 		return "%s" %self.category
 
-
 class Post(models.Model):
-	title = models.CharField(max_length=240,blank=False)
+	title = models.CharField(max_length=240,blank=False, unique=True)
 	entry = RichTextField()
 	pub_date = models.DateField(default=datetime.datetime.now)
 	category = models.ForeignKey(Category)
 	blog = models.ForeignKey(Blog)
-	perma_link = models.CharField(max_length=50,blank = True)
-	#colour = models.ForeignKey(Category.colour)
+	publish = models.CharField(default="No", 
+								max_length = 3, 
+								choices=[("Yes", "Yes"),
+										 ("No", "No")
+										 ],
+								)
+	def get_absolute_url(self):
+		return "/p/b%sp%s" %(self.blog.pk,self.pk)
 
-	# https://docs.djangoproject.com/en/1.6/topics/db/models/#overriding-model-methods
-	def save(self, *args, **kwargs):
-		super(Post,self).save(*args,**kwargs)
-		if self.perma_link =='':
-			self.perma_link = "b%sp%s" %(self.blog.pk,self.pk)
-			self.save(*args, **kwargs)
-			
 	def __unicode__(self):
 		return "%s" %self.title
 
-class Comment(models.Model):
-	comment = models.TextField(blank=False)
-	handle = models.CharField(max_length=25, default="Anonymous")
-	post = models.ForeignKey(Post)
-
