@@ -126,19 +126,6 @@ def perma_post(request,blog_pk,post_pk):
 		context_dict['DISQUS_SHORTNAME'] = settings.BOOTLOG_DISQUS_SHORTNAME
 	return render(request,context_dict['base_page'],context_dict)
 
-import logging
-logger = logging.getLogger(__name__)
-def view_404(request):
-	context_dict['msg']='Why a 404!!!'
-	context_dict['category_split'] = get_category_post_count()
-	logger.error("Got a 404")
-	logger.debug("Got a 404")
-	logger.info("Got a 404")
-	logger.warning("Got a 404")
-	logger.critical("Got a 404")
-	return render(request,'bootlog/404.html',context_dict)
-
-
 class LatestEntriesFeed(Feed):
 	title = context_dict['RSS']['title']
 	link =  context_dict['RSS']['link']
